@@ -10,6 +10,7 @@ fi
 
 # Unset video posting - it's not needed for suspend to disk
 unset POST_VIDEO
+unset USE_DPMS
 
 . /etc/acpi/prepare.sh
 
@@ -25,7 +26,18 @@ unset POST_VIDEO
 #fi
 
 echo -n $HIBERNATE_MODE >/sys/power/disk
-echo -n "disk" >/sys/power/state
+
+if [ -x /sbin/s2disk ]; then
+    DEVICE="/dev/disk/by-uuid/`awk -F= '{print $3}' </etc/initramfs-tools/conf.d/resume`"
+    if [ -f /etc/usplash.conf ]; then
+	. /etc/usplash.conf
+	/sbin/s2disk -x "$xres" -y "$yres" $DEVICE
+    else
+	/sbin/s2disk $DEVICE
+    fi
+else
+    echo -n "disk" >/sys/power/state
+fi
 
 $LAPTOP_MODE stop
 
