@@ -6,13 +6,13 @@
 function laptop_mode_enable {
     $LAPTOP_MODE start
     
-    for x in /sys/bus/ide/devices/*/block; do 
+    for x in /sys/bus/ide/devices/*/block*; do 
 	drive=$(basename $(readlink $x));
 	$HDPARM -S $SPINDOWN_TIME /dev/$drive 2>/dev/null
 	$HDPARM -B 1 /dev/$drive 2>/dev/null
     done
     
-    for x in /sys/bus/scsi/devices/*/block; do 
+    for x in /sys/bus/scsi/devices/*/block*; do 
 	drive=$(basename $(readlink $x));
 	$HDPARM -S $SPINDOWN_TIME /dev/$drive 2>/dev/null
 	$HDPARM -B 1 /dev/$drive 2>/dev/null
@@ -20,12 +20,12 @@ function laptop_mode_enable {
 }
 
 function laptop_mode_disable {
-    for x in /sys/bus/ide/devices/*/block; do 
+    for x in /sys/bus/ide/devices/*/block*; do 
 	drive=$(basename $(readlink $x));
 	$HDPARM -S 0 /dev/$drive 2>/dev/null
 	$HDPARM -B 255 /dev/$drive 2>/dev/null
     done
-    for x in /sys/bus/scsi/devices/*/block; do 
+    for x in /sys/bus/scsi/devices/*/block*; do 
 	drive=$(basename $(readlink $x));
 	$HDPARM -S 0 /dev/$drive 2>/dev/null
 	$HDPARM -B 255 /dev/$drive 2>/dev/null
@@ -57,4 +57,4 @@ for x in /proc/acpi/ac_adapter/*; do
 	    (sleep 5 && laptop_mode_disable)&
 	fi
     fi
-done
\ No newline at end of file
+done
