@@ -1,5 +1,7 @@
 #!/bin/bash
 
 for SCRIPT in /etc/acpi/suspend.d/*.sh; do
-  . $SCRIPT
+    if [ -x $SCRIPT ]; then
+	. $SCRIPT
+    fi
 done
\ No newline at end of file
